@@ -2,7 +2,7 @@
 
 # test.pl
 # Copyright (C) 1997 by USC/ISI
-# $Id: test.pl,v 1.7 1999/06/30 20:21:21 mthurn Exp $
+# $Id: test.pl,v 1.19 1999/07/14 18:47:53 mthurn Exp $
 #
 # Copyright (c) 1997 University of Southern California.
 # All rights reserved.                                            
@@ -64,11 +64,11 @@ $do_internal = $do_external = 0;
 ($do_internal, $do_external) = (1,1) unless ($do_internal || $do_external);
 
 my $error_count = 0;
-my($fullperl);
+my $fullperl;
 my ($date, $pwd);
-my($MODE_DUMMY, $MODE_INTERNAL, $MODE_EXTERNAL, $MODE_UPDATE) = (0..10);
-my($TEST_DUMMY, $TEST_EXACTLY, $TEST_BY_COUNTING, $TEST_GREATER_THAN, $TEST_RANGE) = (1..10);
-my($bogus_query) = "Bogus" . "NoSuchWord" . "SpammersAreIdiots";
+my ($MODE_DUMMY, $MODE_INTERNAL, $MODE_EXTERNAL, $MODE_UPDATE) = qw(dummy internal external update);
+my ($TEST_DUMMY, $TEST_EXACTLY, $TEST_BY_COUNTING, $TEST_GREATER_THAN, $TEST_RANGE) = (1..10);
+my $bogus_query = "Bogus" . "NoSuchWord" . "SpammersAreIdiots";
 
 &main();
 
@@ -120,7 +120,7 @@ sub test
   
   return if (!relevant_test($sSE));
   
-  my $path = "test/Pages/$sSE";
+  my $path = "$pwd/test/Pages/$sSE";
   $path =~ s!::!\/!g;
   mkpath $path;
   if ($file =~ m!([^/]+)$!)
@@ -129,28 +129,27 @@ sub test
     } # if
   my $o = new WWW::Search($sSE);
   my $version = $o->version;
-  print "trial $file\n\t($sSE $version, $sM)\n";
-  my(@src);
-  my(@output) = ();
-  $src[$MODE_INTERNAL] = "-o search_from_file=$file";
-  $src[$MODE_EXTERNAL] = "";
-  $src[$MODE_UPDATE] = "-o search_to_file=$file";
-  my($cmd) = &web_search_bin . "-e $sSE $src[$mode] -- '$query'";
-  # $cmd .= " | wc -l | sed 's/ //g'" if ($test_method == $TEST_BY_COUNTING && $mode != $MODE_UPDATE);
+  print "trial $file ($mode)\n\t($sSE $version, $sM)\n";
+  my %src = (
+             $MODE_INTERNAL => "-o search_from_file=$file",
+             $MODE_EXTERNAL => '',
+             $MODE_UPDATE => "-o search_to_file=$file",
+            );
+  my $cmd = &web_search_bin . "-e $sSE $src{$mode} -- $query";
   print "\t$cmd\n" if ($verbose);
   open(TRIALSTREAM, "$cmd|") || die "$0: cannot run test\n";
   open(TRIALFILE, ">$file.trial") || die "$0: cannot open $file.trial\n";
-  open(OUTFILE, ">$file.out") || die "$0: cannot open $file.out\n" if ($mode == $MODE_UPDATE);
+  open(OUTFILE, ">$file.out") || die "$0: cannot open $file.out\n" if ($mode eq $MODE_UPDATE);
+  my $iActual = 0;
   while (<TRIALSTREAM>) 
     {
-    last if /Nothing found./;
     print TRIALFILE $_;
-    print OUTFILE $_ if ($mode == $MODE_UPDATE);
-    push(@output, $_);
+    $iActual++;
+    print OUTFILE $_ if ($mode eq $MODE_UPDATE);
     }
   close TRIALSTREAM;
   close TRIALFILE;
-  if ($mode == $MODE_UPDATE)
+  if ($mode eq $MODE_UPDATE)
     {
     close OUTFILE;
     if (open TS, ">$file.README")
@@ -158,12 +157,11 @@ sub test
       print TS "This set of test-result pages was created on ", scalar(localtime(time)), "\n";
       close TS;
       } # if
-    my $iPageCount = ` wc -l $file `;
-    my $iURLCount = ` wc -l $file.out `;
-    $iPageCount =~ s/\D+//g;
-    $iURLCount =~ s/\D+//g;
+    my $iPageCount = &wc_l($file);
+    my $iURLCount = &wc_l("$file.out");
     my $sExpected = join('..', @_);
     $sExpected .= '..' if ($test_method == $TEST_GREATER_THAN);
+    $sExpected = 0 if $sExpected eq '';
     print "\t$query --> $iURLCount urls (should be $sExpected) on $iPageCount pages\n";
     return;
     } # if
@@ -174,7 +172,6 @@ sub test
     if ($test_method == $TEST_GREATER_THAN) 
       {
       my ($low_end) = @_;
-      my $iActual = scalar(@output);
       if ($iActual < $low_end)
         {
         $sMsg .= ": expected more than $low_end, but got $iActual";
@@ -187,7 +184,6 @@ sub test
       $sMsg .= ": INTERNAL ERROR, low_end has no value" unless defined($low_end);
       $sMsg .= ": INTERNAL ERROR, high_end has no value" unless defined($high_end);
       $sMsg .= ": INTERNAL ERROR, high_end is zero" unless 0 < $high_end;
-      my $iActual = scalar(@output);
       if ($iActual < $low_end)
         {
         $sMsg .= ": expected $low_end..$high_end, but got $iActual";
@@ -201,18 +197,12 @@ sub test
       } # TEST_RANGE
     elsif ($test_method == $TEST_EXACTLY) 
       {
-      my $cmd = "diff -c $file.out $file.trial > $file.diff";
-      print "\t$cmd\n" if $verbose;
-      print STDERR ` $cmd `;
-      $e = (0 < -s "$file.diff") ? 1 : 0;
+      $e = &diff("$file.out", "$file.trial") ? 1 : 0;
       } # TEST_EXACTLY
     elsif ($test_method == $TEST_BY_COUNTING) 
       {
       my $iExpected = shift;
-      my $cmd = "wc -l $file.trial";
-      print "\t$cmd\n" if $verbose;
-      my $iActual = ` $cmd `;
-      $iActual = $1 if $iActual =~ m/(\d+)/;
+      my $iActual = &wc_l("$file.trial");
       if ($iActual != $iExpected)
         {
         $sMsg .= ": expected $iExpected, but got $iActual";
@@ -227,9 +217,8 @@ sub test
 
     if ($e == 0) 
       {
-      print "\tok.\n";
+      print "ok.\n";
       unlink("$file.trial");   # clean up
-      unlink("$file.diff");   # clean up
       } 
     elsif ($e == 1) 
       {
@@ -293,7 +282,7 @@ sub not_working_and_abandonded
 sub test_cases 
   {
   my ($o, $query, $sSE, $sM, $file);
-  ######################################################################
+
   $sSE = 'AltaVista';
   $sM = 'John Heidemann <johnh@isi.edu>';
   
@@ -313,6 +302,7 @@ sub test_cases
   test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 10);
   
   ######################################################################
+
   $sSE = 'AltaVista::Web';
   $sM = 'John Heidemann <johnh@isi.edu>';
   
@@ -329,6 +319,7 @@ sub test_cases
   test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 10);
   
   ######################################################################
+
   $sSE = 'AltaVista::AdvancedWeb';
   $sM = 'John Heidemann <johnh@isi.edu>';
   
@@ -345,18 +336,16 @@ sub test_cases
   test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 10);
   
   ######################################################################
+
   $sSE = 'AltaVista::News';
   $sM = 'John Heidemann <johnh@isi.edu>';
-  
-  $file = 'test/AltaVista/News/multi_result';
-  $query = '+Pe'.'rl +CP'.'AN';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 30); # 30 hits/page
-  
-  $file = 'test/AltaVista/News/zero_result';
   $query = '+pe'.'rl +' . $bogus_query;
-  test($sSE, $sM, $file, $query, $TEST_EXACTLY);
+  test($sSE, $sM, 'zero', $query, $TEST_EXACTLY);
+  $query = '+Pe'.'rl +CP'.'AN';
+  test($sSE, $sM, 'multi', $query, $TEST_GREATER_THAN, 30); # 30 hits/page
   
   ######################################################################
+
   $sSE = 'AltaVista::AdvancedNews';
   $sM = 'John Heidemann <johnh@isi.edu>';
   
@@ -370,161 +359,79 @@ sub test_cases
   
   ######################################################################
 
-  &no_test('AltaVista::Intranet', 'Martin Thurn <MartinThurn@iname.com>');
+  &eval_test('AltaVista::Intranet');
 
   ######################################################################
 
-  $sSE = 'Crawler';
-  $sM = 'unsupported';
-  
-  $file = 'test/Crawler/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/Crawler/one_page_result';
-  $query = 'Bay'.'reuth Bindl'.'acher Be'.'rg Flu'.'gplatz P'.'ilot';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 10);
-  
-  # 10 hits/page
-  $file = 'test/Crawler/two_page_result';
-  $query = 'Fra'.'nkfurter Al'.'lgemeine Sonnt'.'agszeitung Rech'.'erche';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 10);
-  
-  ######################################################################
-  $sSE = 'Dejanews';
-  # $sM = 'Cesare Feroldi de Rosa, <C.Feroldi@IT.net>';
-  $sM = 'Martin Thurn <MartinThurn@iname.com>';
-  
-  $file = 'test/Dejanews/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/Dejanews/multi_result';
-  $query = 'Per'.'l and CP'.'AN';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 101);
+  &no_test('Crawler', 'unsupported');
+  # test($sSE, $sM, 'zero', $bogus_query, $TEST_EXACTLY);
+  # $query = 'Bay'.'reuth Bindl'.'acher Be'.'rg Flu'.'gplatz P'.'ilot';
+  # test($sSE, $sM, 'one', $query, $TEST_RANGE, 2, 10);
+  # # 10 hits/page
+  # $query = 'Fra'.'nkfurter Al'.'lgemeine Sonnt'.'agszeitung Rech'.'erche';
+  # test($sSE, $sM, 'two', $query, $TEST_GREATER_THAN, 10);
   
   ######################################################################
 
+  &eval_test('Dejanews');
+  
   &eval_test('Excite');
-
-  ######################################################################
-
-  $sSE = 'Excite::News';
-  $sM = 'Jim Smyser <jsmyser@bigfoot.com>';
-  
-  test($sSE, $sM, 'zero', $bogus_query, $TEST_BY_COUNTING, 0);
-  test($sSE, $sM, 'one', 'Haw'.'aii AND Alask'.'a', $TEST_RANGE, 1,49);
-  test($sSE, $sM, 'multi', 'pris'.'on* AND esca'.'pe*', $TEST_GREATER_THAN, 51);
+  &eval_test('Excite::News');
 
   ######################################################################
 
   $sSE = 'ExciteForWebServers';
   $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  
-  $file = 'test/ExciteForWebServers/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/ExciteForWebServers/one_page_result';
-  $query = 'bur'.'undi';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 99);
+  &not_working($sSE, $sM);
+  # &test($sSE, $sM, 'zero', $bogus_query, $TEST_EXACTLY);
+  # $query = 'bur'.'undi';
+  # &test($sSE, $sM, 'one', $query, $TEST_RANGE, 2, 99);
   
   ######################################################################
-  $sSE = 'Fireball';
-  $sM = 'unsupported';
-  
-  $file = 'test/Fireball/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/Fireball/one_page_result';
-  $query = '+An'.'na +Kour'.'nikova +Wim'.'bledon +W'.'T'.'A +te'.'nnis';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 10);
-  
-  # 10 hits/page
-  $file = 'test/Fireball/two_page_result';
-  $query = '+Mu'.'rnau +Hinterg'.'lasbilder';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 10);
+
+  &no_test('Fireball', 'unsupported');
+  # test($sSE, $sM, 'zero', $bogus_query, $TEST_EXACTLY);
+  # $query = '+An'.'na +Kour'.'nikova +Wim'.'bledon +W'.'T'.'A +te'.'nnis';
+  # test($sSE, $sM, 'one', $query, $TEST_RANGE, 2, 10);
+  # # 10 hits/page
+  # $query = '+Mu'.'rnau +Hinterg'.'lasbilder';
+  # test($sSE, $sM, 'two', $query, $TEST_GREATER_THAN, 10);
   
   ######################################################################
+
   $sSE = 'FolioViews';
   $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  
-  $file = 'test/FolioViews/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/FolioViews/one_page_result';
+  test($sSE, $sM, 'zero', $bogus_query, $TEST_EXACTLY);
   $query = 'bur'.'undi';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 400);
-  
-  ######################################################################
-  $sSE = 'Gopher';
-  $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  no_test($sSE, $sM);
-  
-  ######################################################################
-  $sSE = 'HotBot';
-  $sM = 'Martin Thurn <MartinThurn@iname.com>';
-  
-  $file = 'test/HotBot/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  # 84 hits/page
-  $file = 'test/HotBot/one_page_result';
-  $query = '"Ch'.'ristie Abbo'.'tt"';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 100);
-  
-  $file = 'test/HotBot/two_page_result';
-  $query = '+IS'.'I +A'.'I +netwo'.'rking';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 101);
-  
-  ######################################################################
-  $sSE = 'HotFiles';
-  $sM = 'Jim Smyser <jsmyser@bigfoot.com>';
-  
-  $file = 'test/HotFiles/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
+  test($sSE, $sM, 'one', $query, $TEST_RANGE, 2, 400);
   
   ######################################################################
 
-  &eval_test('Infoseek');
-  &eval_test('Infoseek::Web');
+  &eval_test('Google');
+  
+  &no_test('Gopher', 'Paul Lindner <paul.lindner@itu.int>');
+
+  &eval_test('HotBot');
+  
+  &eval_test('HotFiles');
+  
   &eval_test('Infoseek::Companies');
+  &eval_test('Infoseek::Email');
   &eval_test('Infoseek::News');
+  &eval_test('Infoseek::Web');
 
-  ######################################################################
-  $sSE = 'Livelink';
-  $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  no_test($sSE, $sM);
+  &no_test('Livelink', 'Paul Lindner <paul.lindner@itu.int>');
+
+  &eval_test('LookSmart');
+
+  &eval_test('Lycos');
   
-  ######################################################################
-  $sSE = 'Lycos';
-  $sM = 'Martin Thurn <MartinThurn@iname.com>';
+  &eval_test('Magellan');
   
-  $file = 'test/Lycos/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/Lycos/one_page_result';
-  $query = '"Chri'.'stie Ab'.'bott"';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 50);
-  
-  $file = 'test/Lycos/multi_page_result';
-  $query = 'repli'.'cation';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 100);
-  
-  ######################################################################
-  $sSE = 'Magellan';
-  $sM = 'Martin Thurn <MartinThurn@iname.com>';
-  
-  $file = 'test/Magellan/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/Magellan/one_page_result';
-  $query = 'dise'.'stablishmentarianism';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 1, 9);
-  
-  # 10 hits/page
-  $file = 'test/Magellan/two_page_result';
-  $query = '+IS'.'I +divisi'.'on';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 11);
+  &not_working('Metacrawler', 'Martin Thurn <MartinThurn@iname.com>');
   
   ######################################################################
+
   $sSE = 'Metapedia';
   $sM = 'Jim Smyser <jsmyser@bigfoot.com>';
   
@@ -532,146 +439,81 @@ sub test_cases
   test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
   
   ######################################################################
+
   $sSE = 'MSIndexServer';
   $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  
-  $file = 'test/MSIndexServer/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/MSIndexServer/one_page_result';
-  $query = 'bur'.'undi';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 99);
+  &not_working($sSE, $sM);
+  # test($sSE, $sM, 'zero', $bogus_query, $TEST_EXACTLY);
+  # $query = 'bur'.'undi';
+  # test($sSE, $sM, 'one', $query, $TEST_RANGE, 2, 99);
   
   ######################################################################
-  $sSE = 'NorthernLight';
-  $sM = 'unsupported';
-  
-  $file = 'test/NorthernLight/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/NorthernLight/one_page_result';
-  $query = '+Bi'.'athlon +weltcu'.'ps +Ath'.'leten +deu'.'tschland';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 25);
-  
-  # 25 hits/page
-  $file = 'test/NorthernLight/two_page_result';
-  $query = '+LS'.'AM +IS'.'I +I'.'B';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 25);
+
+  &eval_test('NorthernLight');
   
   ######################################################################
+
   $sSE = 'Null';
   $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  
-  $file = 'test/Null/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
+  test($sSE, $sM, 'zero', $bogus_query, $TEST_EXACTLY);
   
   ######################################################################
-  $sSE = 'OpenDirectory';
-  $sM = 'Jim Smyser <jsmyser@bigfoot.com>';
-  
-  $file = 'test/OpenDirectory/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
+
+  &eval_test('OpenDirectory');
   
   ######################################################################
+
   $sSE = 'PLweb';
   $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  
-  $file = 'test/PLweb/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/PLweb/one_page_result';
-  $query = 'bur'.'undi';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 99);
+  &not_working($sSE, $sM);
+  # test($sSE, $sM, 'zero', $bogus_query, $TEST_EXACTLY);
+  # $query = 'bur'.'undi';
+  # test($sSE, $sM, 'one', $query, $TEST_RANGE, 2, 99);
   
   ######################################################################
-  $sSE = 'Profusion';
-  $sM = 'Jim Smyser <jsmyser@bigfoot.com>';
-  
-  $file = 'test/Profusion/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/Profusion/one_page_result';
-  $query = 'Astr'.'onomy';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 50);
+
+  &eval_test('Profusion');
   
   ######################################################################
+
   $sSE = 'Search97';
   $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  
-  $file = 'test/Search97/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/Search97/one_page_result';
-  $query = 'bur'.'undi';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 99);
+  &not_working($sSE, $sM);
+  # $file = 'test/Search97/zero_result';
+  # test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
+  # $file = 'test/Search97/one_page_result';
+  # $query = 'bur'.'undi';
+  # test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 99);
   
   ######################################################################
+
   $sSE = 'SFgate';
   $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  
-  $file = 'test/SFgate/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/SFgate/one_page_result';
+  test($sSE, $sM, 'zero', $bogus_query, $TEST_EXACTLY);
   $query = 'bur'.'undi';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 99);
+  test($sSE, $sM, 'one', $query, $TEST_RANGE, 2, 99);
   
   ######################################################################
-  $sSE = 'Snap';
-  $sM = 'Jim Smyser <jsmyser@bigfoot.com>';
+
+  &no_test('Simple', 'Paul Lindner <paul.lindner@itu.int>');
+
+  &eval_test('Snap');
   
-  $file = 'test/Snap/zero_result'; 
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY); 
-  
-  $file = 'test/Snap/one_page_result'; 
-  $query = 'vbt'.'hread'; 
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 99); 
-  
-  $file = 'test/Snap/multi_page_result'; 
-  $query = 'ja'.'bba';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 100); 
-  
-  ######################################################################
-  $sSE = 'Simple';
-  $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  no_test($sSE, $sM);
-  
-  ######################################################################
-  $sSE = 'Verity';
-  $sM = 'Paul Lindner <paul.lindner@itu.int>';
-  no_test($sSE, $sM);
-  
-  ######################################################################
+  &no_test('Verity', 'Paul Lindner <paul.lindner@itu.int>');
 
   &eval_test('WebCrawler');
   
-  ######################################################################
+  &eval_test('Yahoo');
 
-  $sSE = 'Yahoo';
-  $sM = 'Martin Thurn <MartinThurn@iname.com>';
-  
-  $file = 'test/Yahoo/zero_result';
-  test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-  
-  $file = 'test/Yahoo/one_page_result';
-  $query = 'LSA'.'M';
-  test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 84);
-  
-  $file = 'test/Yahoo/two_page_result';
-  $query = 'rep'.'lication';
-  test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 100); # Yahoo seems to have 84 hits/page
+  &eval_test('ZDNet');
 
-  ######################################################################
-  $sSE = 'ZDNet';
-  $sM = 'Jim Smyser <jsmyser@bigfoot.com>';
-  not_working($sSE, $sM);
   } # test_cases
   
+
 sub main 
   {
-  $pwd = `pwd`;
-  chomp($pwd);
-  
+  use Cwd;
+  $pwd = cwd;
   $fullperl = $Config{'perlpath'};
   
   #    print "\n\nWWW::Search version " . $WWW::Search::VERSION . "\n";
@@ -687,26 +529,78 @@ sub main
     return;
     }
   
-  if ($do_internal) {
+  if ($do_internal) 
+    {
     print "\nTESTING INTERNAL PARSING.\n\t(Errors here should be reported to the WWW::Search maintainer.)\n\n";
+    $error_count = 0;
     $mode = $MODE_INTERNAL;
     &test_cases();
-    }
-  
-  if ($do_external) {
+    print "\n";
+    if ($error_count <= 0) 
+      {
+      print "All $mode tests have passed.\n\n";
+      }
+    else 
+      {
+      print "Some $mode tests failed.  Please check the README file before reporting errors (sometimes back-ends have known failures).\n";
+      }
+    } # if $do_internal
+    
+  if ($do_external) 
+    {
     print "\n\nTESTING EXTERNAL QUERIES.\n\t(Errors here suggest search-engine reformatting and should be\n\treported to the maintainer of the back-end for the search engine.)\n\n";
+    $error_count = 0;
     $mode = $MODE_EXTERNAL;
     &test_cases();
-    };
+    print "\n";
+    if ($error_count <= 0) 
+      {
+      print "All $mode tests have passed.\n\n";
+      }
+    else 
+      {
+      print "Some $mode tests failed.  Please check the README file before reporting errors (sometimes back-ends have known failures).\n";
+      }
+    } # if $do_external
   
-  print "\n";
-  if ($error_count == 0) {
-    print "All tests have passed.\n\n";
-    } else {
-      print "Some tests failed.  Please check the README file in the distribution before reporting errors (sometimes back-ends have known failures).\n";
-      };
   } # main
 
+sub wc_l ($)
+  {
+  # Given a filename, count the number of lines of text contained
+  # within the file.  (I.e. simulate running UNIX command wc -l on it)
+  # SPECIAL CASE: If first line is "Nothing found.", report 0 lines.
+  open WC, shift or return 0;
+  $/ = "\n";
+  my $i = 0;
+  while (<WC>)
+    {
+    last if /Nothing found./;
+    $i++;
+    } # while
+  return $i;
+  } # wc_l
+
+sub diff ($$)
+  {
+  # Given two files, returns TRUE if contents are line-by-line
+  # different, or FALSE if contents are line-by-line same
+  open DIFF1, shift or return 91;
+  open DIFF2, shift or return 92;
+  my $iResult = 0;
+  $/ = "\n";
+  while ((defined(my $s1 = <DIFF1>)) &&
+         ($iResult ne 1))
+    {
+    my $s2 = <DIFF2>;
+    $iResult = 1 if $s1 ne $s2;
+    } # while
+  close DIFF1;
+  close DIFF2;
+  return $iResult;
+  } # diff
+
+
 =head2 TO DO
 
 =item  When updating, first delete the files for the existing test results.
